import DescriptionItem from '@/components/DescriptionItem';
import { Badge, Flex } from 'antd';
import classNames from 'classnames';
import EChartsReact from 'echarts-for-react';
import { cloneDeep } from 'lodash';
import React, { memo, useLayoutEffect, useMemo, useRef, useState } from 'react';
import BaseCard from '../components/BaseCard';
import styles from './index.less';
import option, { pieOption } from './option';
/** @name 全市已移交纳入管理综合管廊概况 */
const Overview: React.FC = memo(() => {
  const [activeTab, setActiveTab] = useState('1');

  const [pieData, setPieData] = useState(
    [...Array(4)].map((_, i) => {
      return {
        value: Math.floor(Math.random() * 100),
        name: '给水（输水）管道' + i,
      };
    }),
  );
  const chartRef = useRef<any>();

  const colors = [
    '#5DDDFF',
    '#A550FF',
    '#F07283',
    '#7664EC',
    '#77E67B',
    '#35B2FF',
    '#FFE335',
    '#FF9B5D',
  ];

  const INFO = useMemo(() => {
    return [
      {
        name: '管廊条数',
        value: 82,
        unit: '条',
      },
      {
        name: '管廊长度',
        value: 42,
        unit: '公里',
      },
      {
        name: '舱室总长度',
        value: 40,
        unit: '公里',
      },
    ];
  }, []);

  const tabItems = useMemo(
    () => [
      {
        key: '1',
        label: '管廊区域分布',
      },
      {
        key: '2',
        label: '管廊类型分布',
      },
    ],
    [],
  );

  useLayoutEffect(() => {
    chartRef.current?.resize();
  }, []);

  const BarOption = useMemo(() => {
    const temp = cloneDeep(option) as any;
    const xAxis = [
      '市本级',
      '天府新区',
      '高新区',
      '未来科技城',
      '双流区',
      '金堂县',
      '其它区（市）县',
    ];
    const yAxis = [1652, 1652, 1652, 1652, 1652, 1652, 1652];
    temp.xAxis[0].data = xAxis;
    temp.series[0].data = yAxis;
    return temp;
  }, []);

  const PieOption = useMemo(() => {
    const temp = cloneDeep(pieOption) as any;
    temp.color = colors;
    temp.series[0].data = pieData;
    return temp;
  }, []);

  return (
    <BaseCard w={902} h={394} title="全市已移交纳入管理综合管廊概况">
      <Flex gap={100} style={{ marginTop: 20 }} align="center">
        {INFO.map((item) => {
          return (
            <DescriptionItem
              value={item.value}
              unit={item.unit}
              name={item.name}
              key={item.name}
            />
          );
        })}
      </Flex>

      <Flex gap={36} style={{ marginTop: 20 }}>
        {tabItems.map((item, index) => {
          return (
            <div
              key={index}
              onClick={() => {
                setActiveTab(item.key);
              }}
              className={classNames(styles.tabItem, {
                [styles.active]: activeTab === item.key,
              })}
            >
              {item.label}
            </div>
          );
        })}
      </Flex>

      {activeTab === '1' ? (
        <div>
          <div style={{ margin: '10px 0' }}>单位：km</div>
          <EChartsReact
            ref={chartRef}
            style={{
              height: 130,
            }}
            option={BarOption}
          ></EChartsReact>
        </div>
      ) : (
        <Flex align="center" gap={60} className={styles.container}>
          <div
            style={{
              height: 130,
              width: 130,
            }}
          >
            <EChartsReact
              ref={chartRef}
              style={{
                height: 130,
                width: 130,
              }}
              option={PieOption}
            ></EChartsReact>
          </div>

          <div className={styles.legendContent}>
            {pieData.map((item, index) => {
              return (
                <Flex key={index} className={styles.legendBg} gap={14}>
                  <Badge color={colors[index % colors.length]} />
                  <div>
                    <div>{item.name}</div>
                    <div>{item.value} 条</div>
                  </div>
                </Flex>
              );
            })}
          </div>
        </Flex>
      )}
    </BaseCard>
  );
});

export default Overview;
