import DescriptionItem from '@/components/DescriptionItem';
import { useGlobalModalServices } from '@/pages/GlobalModalServices/provider';
import React from 'react';
import DataElement from './components/DataElement';
import ManagementElement from './components/ManagementElement';
import PerceptionSource from './components/PerceptionSource';
import styles from './index.less';
import Card from './components/Card';
import { ConfigProvider, Popover } from 'antd';
import rightBack from '@/assets/images/newMain/rightBack.png';
import classNames from 'classnames';
const ResourceElements: React.FC = () => {
  const { dispatch } = useGlobalModalServices();
  const commonValueStyle = {
    background: 'linear-gradient(180deg, #AAFFF6 0%, #25BBFF 100%)',
    WebkitBackgroundClip: 'text',
    WebkitTextFillColor: 'transparent',
    fontFamily: 'D-DIN',
    fontSize: '36px',
    fontWeight: 700,
  };

  const commonLabelStyle = {
    color: '#BCCEE9',
    // fontFamily: '微软雅黑',
    fontSize: '20px',
    fontWeight: 400,
    lineHeight: 1.1,

    // marginLeft: '100px',
  };

  const valueStyle = {
    ...commonValueStyle,
    marginLeft: '50px',
  };

  const labelStyle = {
    ...commonLabelStyle,
    marginTop: '-5px',
  };

  const commonUnitStyle = {
    color: '#BCCEE9',
    // fontFamily: '微软雅黑',
    fontSize: '20px',
    fontWeight: 400,
    lineHeight: 1.1,
  };
  const cards = [
    {
      title: '数据要素',
      children: <DataElement />,
    },
    {
      title: '管理要素',
      children: <ManagementElement />,
      popverSystem: [
        {
          name: '网格基座',
          url: 'https://10.1.174.34:13600/user/autoLogin',
        },
      ],
    },
    {
      title: '感知源',
      children: <PerceptionSource />,
      popverSystem: [
        {
          name: '物联感知平台',
          url: 'https://10.1.174.34:13200/iot-platform-screen',
        },
      ],
    },
  ];
  const handleClick = (item: { url?: string; onClick?: () => void }) => {
    if (item.onClick) {
      item.onClick();
    } else if (item.url) {
      window.open(item.url, '_blank');
    }
  };
  const jumpSystem=[{
    name: '网格基座',
    url: 'https://10.1.174.34:13600/user/autoLogin',
    
  },{
    name: '物联感知平台',
    url: 'https://10.1.174.34:13200/iot-platform-screen',
  },]
  return (
    <div className={styles.container}>
      <div style={{display:'flex',justifyContent:'space-between',alignItems:'center'}}>
      <div className={styles.title}>
        <span>城管资源要素</span>
        
      </div>
      <ConfigProvider
          theme={{
            token: {
              sizePopupArrow: 0,
              colorBgElevated: 'rgba(41, 84, 136, 0.95)',
            },
          }}
        >
          <Popover
            trigger={'click'}
            content={
              <div className={styles.otherSystem}>
                {jumpSystem?.map((it) => (
                  <div key={it.name} className={styles.systemItem}>
                    <span onClick={() => handleClick(it)}>{it.name}</span>
                  </div>
                ))}
              </div>
            }
            placement="bottomRight"
          >
            <div
              className={classNames(styles.rightBtn, {
                [styles.bindClick]: !Boolean(jumpSystem?.length),
              })}
            >
              <img src={rightBack} alt="" />
            </div>
          </Popover>
        </ConfigProvider>
      </div>
      
      <div className={styles.content}>
     
        <DescriptionItem
          onClick={() => {
            dispatch.push('DataGovernance');
          }}
          value={11.52}
          decimals={2}
          name="汇聚数据"
          unit="亿条"
          valueStyle={{
            background: 'linear-gradient(180deg, #AAFFF6 0%, #25BBFF 100%)',
            WebkitBackgroundClip: 'text',
            WebkitTextFillColor: 'transparent',
            fontFamily: 'D-DIN',
            fontSize: '36px',
            fontWeight: 700,
            lineHeight: 1.1,
          }}
          labelStyle={{
            color: '#BCCEE9',
            // fontFamily: 'DingTalk JinBuTi',
            fontSize: '20px',
            fontWeight: 400,
            lineHeight: 1.1,
          }}
          unitStyle={{
            color: '#BCCEE9',
            // fontFamily: '微软雅黑',
            fontSize: '20px',
            fontWeight: 400,
            lineHeight: 1.1,
          }}
        />
        <DescriptionItem
          value={1152}
          decimals={0}
          name="网格"
          unit="个"
          valueStyle={{
            background: 'linear-gradient(180deg, #AAFFF6 0%, #25BBFF 100%)',
            WebkitBackgroundClip: 'text',
            WebkitTextFillColor: 'transparent',
            fontFamily: 'D-DIN',
            fontSize: '36px',
            fontWeight: 700,
            lineHeight: 1.1,
          }}
          labelStyle={{
            color: '#BCCEE9',
            // fontFamily: 'DingTalk JinBuTi',
            fontSize: '20px',
            fontWeight: 400,
            lineHeight: 1.1,
          }}
          unitStyle={{
            color: '#BCCEE9',
            // fontFamily: '微软雅黑',
            fontSize: '20px',
            fontWeight: 400,
            lineHeight: 1.1,
          }}
        />
         <DescriptionItem
        
          value={9.4}
          decimals={2}
          name="资源"
          unit="万个"
          valueStyle={{
            background: 'linear-gradient(180deg, #AAFFF6 0%, #25BBFF 100%)',
            WebkitBackgroundClip: 'text',
            WebkitTextFillColor: 'transparent',
            fontFamily: 'D-DIN',
            fontSize: '36px',
            fontWeight: 700,
            lineHeight: 1.1,
          }}
          labelStyle={{
            color: '#BCCEE9',
            // fontFamily: 'DingTalk JinBuTi',
            fontSize: '20px',
            fontWeight: 400,
            lineHeight: 1.1,
          }}
          unitStyle={{
            color: '#BCCEE9',
            // fontFamily: '微软雅黑',
            fontSize: '20px',
            fontWeight: 400,
            lineHeight: 1.1,
          }}
        />
         <DescriptionItem
         
          value={304.6}
          decimals={2}
          name="部件"
          unit="万个"
          valueStyle={{
            background: 'linear-gradient(180deg, #AAFFF6 0%, #25BBFF 100%)',
            WebkitBackgroundClip: 'text',
            WebkitTextFillColor: 'transparent',
            fontFamily: 'D-DIN',
            fontSize: '36px',
            fontWeight: 700,
            lineHeight: 1.1,
          }}
          labelStyle={{
            color: '#BCCEE9',
            // fontFamily: 'DingTalk JinBuTi',
            fontSize: '20px',
            fontWeight: 400,
            lineHeight: 1.1,
          }}
          unitStyle={{
            color: '#BCCEE9',
            // fontFamily: '微软雅黑',
            fontSize: '20px',
            fontWeight: 400,
            lineHeight: 1.1,
          }}
        />
         <DescriptionItem
         
         value={238}
         decimals={0}
         name="感知源"
         unit="万个"
         valueStyle={{
           background: 'linear-gradient(180deg, #AAFFF6 0%, #25BBFF 100%)',
           WebkitBackgroundClip: 'text',
           WebkitTextFillColor: 'transparent',
           fontFamily: 'D-DIN',
           fontSize: '36px',
           fontWeight: 700,
           lineHeight: 1.1,
         }}
         labelStyle={{
           color: '#BCCEE9',
           // fontFamily: 'DingTalk JinBuTi',
           fontSize: '20px',
           fontWeight: 400,
           lineHeight: 1.1,
         }}
         unitStyle={{
           color: '#BCCEE9',
           // fontFamily: '微软雅黑',
           fontSize: '20px',
           fontWeight: 400,
           lineHeight: 1.1,
         }}
       />
      </div>
    </div>
  );
};

export default ResourceElements;
